#!/bin/bash

set -ex

version=5.48.0

# install PHPUnit

# Prepare database
mysql -p"$DB_ROOT_PASSWORD" -u root -h $WORDPRESS_DB_HOST -e "DROP USER IF EXISTS '${WORDPRESS_DB_USER}'; FLUSH PRIVILEGES; CREATE USER '${WORDPRESS_DB_USER}' IDENTIFIED BY '${WORDPRESS_DB_PASSWORD}';"

for db in "${WORDPRESS_DB_NAME}" "${CIVI_DB_NAME}" ; do
    mysql -p"$DB_ROOT_PASSWORD" -u root -h $WORDPRESS_DB_HOST -e "DROP DATABASE IF EXISTS ${db}; CREATE DATABASE ${db} CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci; GRANT ALL PRIVILEGES ON ${db}.* TO '${WORDPRESS_DB_USER}'"
done

# # Download codebase
# wp core download --version=$WP_VERSION

# Set config
cp wp-config-sample.php wp-config.php
wp config shuffle-salts
wp config set DB_HOST "${WORDPRESS_DB_HOST}:3306"
wp config set DB_NAME "$WORDPRESS_DB_NAME"
wp config set DB_USER "$WORDPRESS_DB_USER"
wp config set DB_PASSWORD "$WORDPRESS_DB_PASSWORD"
wp config set WP_DEBUG "true"
wp config set WP_DEBUG_LOG "true"

# Install
wp db check
wp core install \
    --url="$WORDPRESS_HOST" \
    --title="$WORDPRESS_NAME" \
    --admin_user="$WORDPRESS_ADMIN_USER" \
    --admin_password="$WORDPRESS_ADMIN_PASSWORD" \
    --admin_email="$WORDPRESS_ADMIN_EMAIL" \
    --skip-email

# Set languages
wp language core install nl_NL
wp site switch-language nl_NL

# Install CiviCRM
PLUGIN_DIR=`pwd`/wp-content/plugins

# Configure CivCRM
#rm -f -- wp-content/uploads/civicrm/civicrm.settings.php
cv --no-interaction core:install -vv --setup-path=$PLUGIN_DIR/civicrm \
    --src-path=$PLUGIN_DIR/civicrm/civicrm \
    --user=www-data \
    --cms-base-url="https://${WORDPRESS_HOST}" \
    --lang=nl_NL \
    --db "mysql://$WORDPRESS_DB_USER:$WORDPRESS_DB_PASSWORD@$WORDPRESS_DB_HOST/$CIVI_DB_NAME"

wp plugin activate civicrm
cp wp-content/uploads/civicrm/civicrm.settings.php wp-content/uploads/civicrm/civicrm.settings.php.bak

cv upgrade:db

# Install extensions
cd wp-content/uploads/civicrm/ext

cv ext:enable de.systopia.identitytracker
cv ext:enable org.project60.banking
cv ext:enable civirules
cv ext:enable assignee
cv ext:enable apikey
cv ext:enable dataprocessor
cv ext:enable emailapi
cv ext:enable action-provider
cv ext:enable form-processor

cv ext:enable de.systopia.xcm
cv ext:enable group2summary
cv ext:enable org.project60.bic
# cv ext:enable org.project60.sepa
# cv ext:enable org.civicrm.contactlayout
# cv ext:enable org.civicrm.recentmenu
# cv ext:enable org.wikimedia.relationshipblock
# cv ext:enable uk.co.vedaconsulting.mosaico

cv ext:enable bij1algemeen
cv ext:enable bij1migratie
cv ext:enable bij1rules

cv ext:upgrade-db

cd /var/www/civi
wp plugin install --activate civicrm-admin-utilities wp-mail-smtp wpforms-lite

echo `wp option get siteurl`/wp-admin/admin.php?page=civi_options
